@@ -44,8 +44,10 @@ class TrainingJob(object):
 
         @返回值: 无
         """
+        training_channels = None
+        if inputs is not None:
+            training_channels = self._prepare_input_channels(inputs=inputs)
 
-        training_channels = self._prepare_input_channels(inputs=inputs)
         output_config = self._prepare_output_config(
             output_path=self.estimator.output_path
         )
